
	Comment ( Common engine settings for pschlik physics. )
	Comment ( Same settings used by all locomotives for consistency and compatibility. )
	Comment ( Assumes 26L brake schedule with 6 pound reduction minimum. )
	Comment ( Assumes MR operating pressure of 130 - 140 psi . )
	Comment ( More specific braking characteristics can be found in other files. )
	Comment ( Stats are somewhat based on real life, what "feels good," all while providing an interesting challenge. )
	Comment ( Properties can be overwritten on an engine-by-engine basis if needed. )
	
	Sanding ( 1e9mph )
	
	ORTSSlipControlSystem ( Full )
	ORTS ( ORTSEmergencyCausesThrottleDown ( 1 ) )
	ORTS ( ORTSEmergencyCausesPowerDown ( 1 ) )
	
	Comment ( Sand consumption of 10.8 cubic feet per hour, most locomotive sandboxes will last a few hours. )
	Comment ( Air consumption of 195 cubic feet per minute, do not sand while recharging the train pipe. )
	ORTSMaxTrackSanderSandConsumption ( 0.003ft^3 )
	ORTSMaxTrackSanderAirConsumption ( 3.25ft^3 )
	
	Comment ( Actual loco brake application and release rate is limited by relay valve. )
	Comment ( Real locomotives only need to pump air into a small hose for engine brakes, which is quite fast. )
	ORTSEngineBrakeApplicationRate ( 48psi/s )
	ORTSEngineBrakeReleaseRate ( 64psi/s )
	
	Comment ( Standard North American direct brake system operates on 0-45 psi. )
	Comment ( Actual brake cylinder developed at locomotive will usually be different due to relay valves. )
	EngineBrakesControllerMaxSystemPressure ( 45psi ) 
	EngineBrakesControllerFullServicePressureDrop ( 0psi )
	EngineBrakesControllerMinPressureReduction ( 0psi )
	
	Comment ( Brake pipe time has been adjusted to produce results similar to data for ABD brake valves in a 1979 study. )
	Comment ( Newer ABDW or ABDX valves can produce substantially faster applications, but OR simulates the ABD most closely. )
	ORTSBrakePipeTimeFactor ( 0.004s )
	ORTSBrakeEmergencyTimeFactor ( 1s )
	ORTSBrakeServiceTimeFactor ( 2.5s )
	
	Comment ( When combined with a brake pipe volume of 1.0 cubic feet, 50 psi/s gives a flow rate of about 200 cfm. )
	ORTSBrakePipeChargingRate ( 50psi/s )
	
	AirBrakesMainMaxAirPressure ( 140psi )
	AirBrakesCompressorRestartPressure ( 130psi )
	AirBrakeMaxMainResPipePressure ( 140psi )
	
	TrainBrakesControllerMinPressureReduction ( 6psi )
	
	TrainBrakesControllerMaxApplicationRate ( 4psi/s )
	TrainBrakesControllerMaxReleaseRate ( 8psi/s )
	TrainBrakesControllerEmergencyApplicationRate ( 25psi/s )
	
	Comment ( Notes in operating procedures menu (F1 key) can confirm the presence or lack of the mod. )
	EngineOperatingProcedures (
		"Physics modifications by pschlik are installed!\n\n"+
		
		"Note that this locomotive will drive differently than normal, this may prevent certain activities from being completed as originally intended!\n"+ 
		"Compatibility with unenhanced stock is not guarenteed, but issues are unlikely.\n"+
		
		"I cannot provide locomotive specific tips, but here are some good train handling practices:\n\n"+
		
		"Starting a train on level ground:\n"+
		"1. Release the train brake and reduce independent brake.\n"+
		"2. Set any DPUs in the back group to notch 1. Advance throttle one notch at a time if remote units can't start the train.\n"+
		"3. Gradually release independent brake as the train begins moving.\n"+
		"4. Continue increasing throttle one notch at a time as needed. Limit remote throttle to 1 or 2 notches above lead throttle.\n\n"+
		
		"Starting a train on ascending grade:\n"+
		"1. Reduce the independent brake setting.\n"+
		"2. Set all DPUs to the back group and set remote traction to notch 1.\n"+
		"3. Increase lead and remote throttle one notch at a time until enough power to prevent rollback is applied.\n"+
		"4. Release the automatic brake and independent brake.\n"+
		"5. Continue increasing throttle one notch at a time as needed as brakes release to get the train moving.\n\n"+
		
		"Starting a train on descending grade:\n"+
		"1. Set all DPUs to the front group, and set maximum dynamic brakes.\n"+
		"2. Release the automatic brake and slowly reduce independent brake until the train starts rolling.\n"+
		"3. Release the independent brake when the dynamic brakes take effect.\n"+
		"4. Re-apply the automatic brake if maximum dynamic brake effort cannot hold train speed.\n\n"+
		
		"Reducing speed:\n"+
		"Always try to reduce speed first by coasting, second with dynamic brakes, and only use air brakes if needed.\n"+
		"1. Gradually reduce power on the lead and DP consists, limit remote throttle to 1 or 2 notches above lead.\n"+
		"2. Enter dynamic braking on the lead consist, leaving DPUs in traction mode to bunch slack.\n"+
		"3. Adjust lead dynamic brakes to manage speed.\n"+
		"4. If maximum dynamic braking is insufficient, reduce remote throttle to idle and gradually apply remote dynamics.\n"+
		"5. Keep lead dynamic brake at maximum, and adjust remote dynamic brake to manage speed.\n"+
		"6. If maximum dynamic brake on all locomotives isn't enough, apply train brakes and bail off.\n"+
		"7. Leave lead consist in max dynamic braking while air brakes are applied, use remote dynamics to manage speed.\n"+
		"8. Follow process in reverse as less braking effort is needed, but never reduce lead dynamics below remote dynamics.\n\n"+
		
		"Stopping a train:\n"+
		"1. Slowly reduce lead and remote throttle setting toward idle. Limit remote throttle to 1 or 2 notches above lead throttle.\n"+
		"2. Gradually increase dynamic braking on lead consist until full dynamic braking is achieved.\n"+
		"3. Slowly reduce remote throttle to idle, then slowly increase remote dynamic brakes towards maximum.\n"+
		"4. With maximum dynamic brakes applied, make a minimum automatic brake application, and bail off.\n"+
		"5. Gradually increase automatic brake reduction and bail off as required to stop in the desired location.\n"+
		"6. As dynamic brakes lose effectiveness, apply the independent brake.\n"+
		"7. Make a final reduction in train brake pressure as the train comes to a stop.\n"+
		"8. One train is stopped, disable dynamic brakes and set maximum independent brake.\n\n"+
		
		"Note that all of these strategies can take minutes to play out! Be sure to plan ahead."
	) 
	